%global pypi_name tifffile

Name:           python-%{pypi_name}
Version:        2024.8.30
Release:        %mkrel 1
Summary:        Read and write TIFF(r) files
Group:          Development/Python
License:        BSD
URL:            https://www.lfd.uci.edu/~gohlke/
Source0:        %{pypi_source}

BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(pytest)

%description
Tifffile is a Python library to:
 * store numpy arrays in TIFF (Tagged Image File Format) files, and
 * read image and metadata from TIFF-like files used in bioimaging.

%package -n python3-%{pypi_name}
Summary:        Read and write TIFF(r) files
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
Tifffile is a Python library to:
 * store numpy arrays in TIFF (Tagged Image File Format) files, and
 * read image and metadata from TIFF-like files used in bioimaging.

%prep
%autosetup -n %{pypi_name}-%{version}

sed -i -e "1d" tifffile/lsm2bin.py
sed -i 's/\r$//' README.rst

%generate_buildrequires
%pyproject_buildrequires -x tests

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS='-p no:cacheprovider'
export PYTHONPATH="${PYTHONPATH:-%{buildroot}%{python3_sitearch}:%{buildroot}%{python3_sitelib}}"
# 7 tests fail out of 1000
# these tests require network or additional packages not in Fedora
pytest-%{python3_version} -v tests \
 --deselect=tests/test_tifffile.py::test_issue_infinite_loop \
 --deselect=tests/test_tifffile.py::test_issue_jpeg_ia \
 --deselect=tests/test_tifffile.py::test_func_pformat_xml \
 --deselect=tests/test_tifffile.py::test_filehandle_seekable \
 --deselect=tests/test_tifffile.py::test_read_cfa \
 --deselect=tests/test_tifffile.py::test_read_tiles \
 --deselect=tests/test_tifffile.py::test_write_cfa \
 --deselect=tests/test_tifffile.py::test_write_volume_png \
 --deselect=tests/test_tifffile.py::test_class_omexml \
 --deselect=tests/test_tifffile.py::test_write_ome \
 --deselect=tests/test_tifffile.py::test_write_3gb \
 --deselect=tests/test_tifffile.py::test_write_bigtiff \
 --deselect=tests/test_tifffile.py::test_write_imagej_raw \
 --deselect=tests/test_tifffile.py::test_issue_trucated_tileoffsets \
 --deselect=tests/test_tifffile.py::test_write_6gb \
 --deselect=tests/test_tifffile.py::test_write_5GB_fails \
 --deselect=tests/test_tifffile.py::test_write_5GB_bigtiff
# deselect the last three because they use large amounts of memory and time

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%{_bindir}/lsm2bin
%{_bindir}/tiffcomment
%{_bindir}/tifffile
%{_bindir}/tiff2fsspec


%changelog
* Tue Sep 03 2024 daviddavid <daviddavid> 2024.8.30-1.mga10
+ Revision: 2092919
- new version: 2024.8.30

* Sun Aug 25 2024 daviddavid <daviddavid> 2024.8.10-1.mga10
+ Revision: 2091163
- new version: 2024.8.10

* Tue Aug 06 2024 daviddavid <daviddavid> 2024.7.24-1.mga10
+ Revision: 2083744
- new version: 24.7.24

* Fri Jun 28 2024 daviddavid <daviddavid> 2024.6.18-1.mga10
+ Revision: 2077849
- new version: 2024.6.18

* Fri May 31 2024 daviddavid <daviddavid> 2024.5.22-1.mga10
+ Revision: 2068951
- new version: 2024.5.22

* Mon May 20 2024 daviddavid <daviddavid> 2024.5.3-1.mga10
+ Revision: 2065266
- new version: 2024.5.3

* Sun Apr 21 2024 daviddavid <daviddavid> 2024.4.18-1.mga10
+ Revision: 2060186
- new version: 2024.4.18

* Sun Feb 18 2024 daviddavid <daviddavid> 2024.2.12-1.mga10
+ Revision: 2042326
- new version: 2024.2.12

* Tue Feb 06 2024 daviddavid <daviddavid> 2024.1.30-1.mga10
+ Revision: 2037922
- new version: 2024.1.30

* Mon Dec 25 2023 wally <wally> 2023.12.9-1.mga10
+ Revision: 2021322
- new version 2023.12.9
+ papoteur <papoteur>
- Mass Rebuild - Python 3.12

* Mon Oct 02 2023 daviddavid <daviddavid> 2023.9.26-1.mga10
+ Revision: 1993099
- new version: 2023.9.26

* Wed Sep 06 2023 daviddavid <daviddavid> 2023.8.30-1.mga10
+ Revision: 1984596
- new version: 2023.8.30

* Wed Aug 30 2023 daviddavid <daviddavid> 2023.8.25-1.mga10
+ Revision: 1981857
- new version: 2023.8.25
- switch to pyproject

* Tue Mar 29 2022 umeabot <umeabot> 2022.2.9-2.mga9
+ Revision: 1832827
- Mageia 9 Mass Rebuild

* Wed Feb 23 2022 mrambo3501 <mrambo3501> 2022.2.9-1.mga9
+ Revision: 1783584
- version 2022.2.9
- rebuild for python-3.10

* Tue Apr 20 2021 daviddavid <daviddavid> 2021.4.8-1.mga9
+ Revision: 1717510
- new version: 2021.4.8

* Tue Apr 20 2021 daviddavid <daviddavid> 2020.7.4-1.mga9
+ Revision: 1717307
- initial package python-tifffile

